@@ -252,6 +252,9 @@
 #' 
 #' # fit a dipm classification tree 
 #' tree1=dipm(Y~treatment | .,data,mtry=1,maxdepth=3)
+#' # predict optimal treatment for new subjects
+#' predict(tree1, newdata=head(data), 
+#' FUN = function(n)  as.numeric(n$info$opt_trt))
 #'
 #'\donttest{
 #' #
@@ -464,7 +467,7 @@ dipm <- function(formula,
     treatment=data[,form_rhs[1]]
 
 #    determine appropriate method from data and value of "mtry"
-    ntrts=length(levels(as.factor(treatment)))
+    ntrts=nlevels(as.factor(treatment))
 
     if ( ntrts <= 1 ) {
         stop("At least 2 treatment groups are required.")
@@ -547,7 +550,7 @@ dipm <- function(formula,
         types=rep(2,nc) # default is to assume all candidate
                         # split variables are ordinal
 
-        prinm("Note that all candidate split variables are assumed to be ordinal.")
+        message("Note that all candidate split variables are assumed to be ordinal.")
 
     } else {
 
@@ -613,7 +616,8 @@ dipm <- function(formula,
                mtry=mtry,
                maxdepth=maxdepth,
                maxdepth2=maxdepth2,
-               method=method)
+               method=method,
+               environment(lm_R_to_C))
 
     rm(XC)
 
